package com.goldenwater.slaj.stan.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.stan.mapper.BisScenReviMapper;
import com.goldenwater.slaj.stan.domain.BisScenRevi;
import com.goldenwater.slaj.stan.service.IBisScenReviService;

@Service
public class BisScenReviServiceImpl implements IBisScenReviService {
    @Autowired
    private BisScenReviMapper bisScenReviMapper;

    @Override
    public BisScenRevi selectBisScenReviByGuid(String guid) { return bisScenReviMapper.selectBisScenReviByGuid(guid); }
    @Override
    public List<BisScenRevi> selectBisScenReviList(BisScenRevi bisScenRevi) { return bisScenReviMapper.selectBisScenReviList(bisScenRevi); }
    @Override
    public int insertBisScenRevi(BisScenRevi bisScenRevi) { return bisScenReviMapper.insertBisScenRevi(bisScenRevi); }
    @Override
    public int updateBisScenRevi(BisScenRevi bisScenRevi) { return bisScenReviMapper.updateBisScenRevi(bisScenRevi); }
    @Override
    public int deleteBisScenReviByGuid(String guid) { return bisScenReviMapper.deleteBisScenReviByGuid(guid); }
    @Override
    public int deleteBisScenReviByGuids(String[] guids) { return bisScenReviMapper.deleteBisScenReviByGuids(guids); }
}
